@@ -92,21 +92,41 @@ def sin(a: Numeric):
     return anp.sin(a)
 
 
+@dispatch
+def arcsin(a: Numeric):
+    return anp.arcsin(a)
+
+
 @dispatch
 def cos(a: Numeric):
     return anp.cos(a)
 
 
+@dispatch
+def arccos(a: Numeric):
+    return anp.arccos(a)
+
+
 @dispatch
 def tan(a: Numeric):
     return anp.tan(a)
 
 
+@dispatch
+def arctan(a: Numeric):
+    return anp.arctan(a)
+
+
 @dispatch
 def tanh(a: Numeric):
     return anp.tanh(a)
 
 
+@dispatch
+def arctanh(a: Numeric):
+    return anp.arctanh(a)
+
+
 @dispatch
 def erf(a: Numeric):
     return asps.erf(a)
