@@ -45,7 +45,7 @@ def isnan(a: Numeric):
 
 @dispatch
 def device(a: TFNumeric):
-    return str(a.device)
+    return a.device
 
 
 @dispatch
@@ -123,21 +123,41 @@ def sin(a: Numeric):
     return tf.sin(a)
 
 
+@dispatch
+def arcsin(a: Numeric):
+    return tf.asin(a)
+
+
 @dispatch
 def cos(a: Numeric):
     return tf.cos(a)
 
 
+@dispatch
+def arccos(a: Numeric):
+    return tf.acos(a)
+
+
 @dispatch
 def tan(a: Numeric):
     return tf.tan(a)
 
 
+@dispatch
+def arctan(a: Numeric):
+    return tf.atan(a)
+
+
 @dispatch
 def tanh(a: Numeric):
     return tf.tanh(a)
 
 
+@dispatch
+def arctanh(a: Numeric):
+    return tf.atanh(a)
+
+
 @dispatch
 def erf(a: Numeric):
     return tf.math.erf(a)
